<?php declare(strict_types=1);

namespace Infomaker\Everyware\Base\Models;

use EveryBoard_Renderer;
use Infomaker\Everyware\Support\Interfaces\Selectable;
use Infomaker\Everyware\Support\Str;

/**
 * Everyboard
 *
 * @link    http://infomaker.se
 * @package Infomaker\Everyware\Base\Models
 * @since   Infomaker\Everyware\Base\Models\Everyboard 1.0.0
 */
class Everyboard extends Post implements Selectable
{
    /**
     * @var string
     */
    public const JSON_KEY = 'everyboard_json';

    /**
     * @var string
     */
    protected static $type = 'everyboard';

    public function fillContentContainers(array $objects = []): Everyboard
    {
        add_filter('ew_content_container_fill', function ($arr) use ($objects) {
            return array_merge($arr, $objects);
        });

        return $this;
    }

    /**
     * Retrieve the content of the board in the form of an array or json string if specified
     *
     * @param bool $to_array
     *
     * @return array|string
     */
    public function boardContent(bool $to_array = false)
    {
        $content = $this->getMeta(static::JSON_KEY, []);

        if ( ! \is_array($content) && $to_array) {
            return Str::notEmpty($content) ? json_decode($content, true) : [];
        }

        if ( ! $to_array) {
            return ! empty($content) ? json_encode($content) : '';
        }

        return $content;
    }

    /**
     * Return data in the form of an array fit for a select-box
     * A preselected value may be sent in.
     *
     * @param mixed $selected
     *
     * @return array
     */
    public static function toSelect($selected = null): array
    {
        return static::all()->map(function (self $board) use ($selected) {
            return [
                'value' => $board->id,
                'text' => $board->title(),
                'selected' => $board->id === $selected
            ];
        })->toArray();
    }

    /**
     * Fetches the board json and returns it as raw html.
     *
     * @param array $objects
     *
     * @return string
     */
    public function generate(array $objects = []): string
    {
        if ( ! empty($objects)) {
            $this->fillContentContainers($objects);
        }

        return (new EveryBoard_Renderer())->render([$this->boardContent()]);
    }
}