<?php declare(strict_types=1);

/**
 * Handler: for managing teaser templates used in Everyboard
 */

namespace Infomaker\Everyware\Base;

use EveryBoard_Settings;

/**
 * Templates
 *
 * @link    http://infomaker.se
 * @package Infomaker\Everyware\Handler
 * @since   Infomaker\Everyware\Base\Templates 1.0.0
 */
class Templates
{

    /**
     * Function to fetch all teaser-templates from Everyboard
     *
     * @uses  EveryBoard_Settings::get_templates()
     *
     * @return array
     */
    public static function all(): array
    {
        $templates = [];
        foreach (EveryBoard_Settings::get_templates() as $name => $file) {
            if (pathinfo($file, PATHINFO_EXTENSION) === 'php') {
                $templates[] = [
                    'name' => $name,
                    'file_name' => $file
                ];
            }
        }

        return $templates;
    }

    /**
     * Function to fetch the path to specific teaser-template
     *
     * @param string $template_name
     * @param string $default_template
     *
     * @uses  EveryBoard_Settings::get_template_path()
     *
     * @return string
     */
    public static function getPath(string $template_name, string $default_template = 'ocarticle-default.php'): string
    {
        $template = str_replace('//', '/', EveryBoard_Settings::get_template_path($template_name));

        if (pathinfo($template, PATHINFO_EXTENSION) !== 'php') {
            return static::getPath($default_template);
        }

        return $template;
    }

    /**
     * Retrieve the name of the teaser template set as in "Template Name" comment
     *
     * @param string $template_file
     *
     * @uses  get_file_data()
     *
     * @return string
     */
    public static function getName(string $template_file): string
    {
        if (file_exists($template_file)) {
            $file_data = array_replace(['name' => $template_file],
                get_file_data($template_file, ['name' => 'Template Name']));

            return $file_data['name'];
        }

        return '';
    }

    /**
     * Function to retrieve all teaser-templates as select-box data
     *
     * @return array
     */
    public static function getSelectData(): array
    {
        return array_map(function ($template) {
            return [
                'value' => $template['file_name'],
                'text' => $template['name']
            ];
        }, static::all());
    }
}
